.. rst-class:: detail

Motion
=================

.. currentmodule:: compas_rrc

.. autoclass:: Motion

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~Motion.__init__
    
    